'use strict';

var server = require('server');

server.extend(module.superModule);

const loginHintQueryString = 'loginHint=true';

/**
 * appendLoginHintIfSuccessfulLogin
 * @param {Request} req - The request object.
 * @param {Response} res - The response object.
 * @param {boolean} newlyRegisteredUser - .
 */
function appendLoginHintIfSuccessfulLogin(req, res, newlyRegisteredUser) {
    var accountHelpers = require('*/cartridge/scripts/helpers/accountHelpers');

    var currentViewData = res.getViewData();
    if (!currentViewData.authenticatedCustomer) {
        return;
    }

    var redirectURL = accountHelpers.getLoginRedirectURL(req.querystring.rurl, req.session.privacyCache, newlyRegisteredUser);
    if (redirectURL.includes('?')) {
        redirectURL += '&' + loginHintQueryString;
    } else {
        redirectURL += '?' + loginHintQueryString;
    }
    res.setViewData({
        redirectUrl: redirectURL
    });
}

/**
 * Account-SubmitRegistration : The Account-SubmitRegistration endpoint has been extended to set ownid data in customer profile
 * @name Base/Account-SubmitRegistration
 * @function
 * @memberof Account
 * @param {httpparameter} - dwfrm_profile_customer_firstname - Input field for the shoppers's first name
 * @param {httpparameter} - dwfrm_profile_customer_lastname - Input field for the shopper's last name
 * @param {httpparameter} - dwfrm_profile_customer_phone - Input field for the shopper's phone number
 * @param {httpparameter} - dwfrm_profile_customer_email - Input field for the shopper's email address
 * @param {httpparameter} - dwfrm_profile_customer_emailconfirm - Input field for the shopper's email address
 * @param {httpparameter} - dwfrm_profile_login_password - Input field for the shopper's password
 * @param {httpparameter} - dwfrm_profile_login_passwordconfirm: - Input field for the shopper's password to confirm
 * @param {httpparameter} - dwfrm_profile_customer_ownId_ownIdData - If ownid data was added to the profile form
 * @param {httpparameter} - csrf_token - hidden input field CSRF token
 * @param {category} - sensitive
 * @param {returns} - json
 * @param {serverfunction} - append/prepend
 */
server.append('SubmitRegistration', function (req, res, next) {
    this.on('route:BeforeComplete', function (reqq, ress) {
        appendLoginHintIfSuccessfulLogin(reqq, ress, true);
    });
    return next();
});

server.append('Login', function (req, res, next) {
    this.on('route:BeforeComplete', function (reqq, ress) {
        appendLoginHintIfSuccessfulLogin(reqq, ress, false);
    });
    return next();
});


module.exports = server.exports();
