'use strict';


/**
 * getToggleBasedOnLocale
 * @param {Site} site - .
 * @param {string} preferenceName - .
 * @param {string} lookup - .
 * @returns {boolean} - .
 */
function preferenceContains(site, preferenceName, lookup) {
    var Logger = require('dw/system/Logger');
    var preferenceValues = site.getCustomPreferenceValue(preferenceName);
    if (preferenceValues !== null) {
        for (var value of preferenceValues) {
            Logger.warn('testing {0}: {1} === {2}', preferenceName, value, lookup);
            if (value === 'true' || value === 'all' || value === lookup) {
                return true;
            }
        }
    }
    return false;
}

/**
 * isEnabled
 * @returns {boolean} - .
 */
function isEnabled() {
    var Site = require('dw/system/Site');
    var Locale = require('dw/util/Locale');
    return preferenceContains(Site.getCurrent(), 'enableOwnId', Locale.getLocale(request.locale).ID);
}


/**
 * ownidSdkSnippet
 * @param {string} action - .
 * @returns {string} - .
 */
function ownidSdkSnippet(action) {
    var Site = require('dw/system/Site');
    var URLUtils = require('dw/web/URLUtils');
    var Locale = require('dw/util/Locale');

    if (!isEnabled()) {
        return '';
    }

    const currentSite = Site.getCurrent();
    const env = currentSite.getCustomPreferenceValue('env')
        .getValue()
        .toLowerCase();
    const cdnEnv = env === 'prod' ? '' : '.' + env;
    const sdkUrl = 'https://cdn' + cdnEnv + '.ownid.com/sdk/' + currentSite.getCustomPreferenceValue('appId');

    const widgetsSetupUrl = URLUtils.staticURL('/js/ownid.js');
    const setCookieUrl = URLUtils.url('Ownid-SetCookie')
        .toString();
    const setDataUrl = URLUtils.url('Ownid-Data')
        .toString();
    const getJwtUrl = URLUtils.url('Ownid-Jwt')
        .toString();
    const getMessage = URLUtils.url('Ownid-Message')
        .toString();

    const notAuthenticated = !customer.isAuthenticated();

    const ownidShowReturningUserPrompt = notAuthenticated &&
        preferenceContains(currentSite, 'returningUserPromptActions', action);

    const ownidShowReturningUserPromptOnSecondVisit = notAuthenticated &&
        preferenceContains(currentSite, 'returningUserPromptActionsOnSecondVisit', action);

    const ownidShowAuthNotification = notAuthenticated &&
        preferenceContains(currentSite, 'showAuthNotificationActions', action);

    const ownidShowAccountRecovery = notAuthenticated &&
        preferenceContains(currentSite, 'accountRecoveryActions', action);

    const ownidEnableProfileUpdateWidgets = currentSite.getCustomPreferenceValue('enableProfileUpdateWidgets');

    const locale = Locale.getLocale(request.locale)
        .ID
        .replace('_', '-');

    return (
        'window[\'ownid\'] = window[\'ownid\'] || function() {\n' +
        '    var args = Array.prototype.slice.call(arguments);\n' +
        '    (window[\'ownid\'].q = window[\'ownid\'].q || []).push(args);\n' +
        '    return { error: null, data: null };\n' +
        '};\n' +

        'var sdkScript = document.createElement(\'script\');\n' +
        'sdkScript.src = \'' + sdkUrl + '\';\n' +
        'sdkScript.async = true;\n' +
        'document.head.appendChild(sdkScript);\n' +

        'var widgetsSetupScript = document.createElement(\'script\');\n' +
        'widgetsSetupScript.src = \'' + widgetsSetupUrl + '\';\n' +
        'widgetsSetupScript.async = true;\n' +
        'document.head.appendChild(widgetsSetupScript);\n' +

        'window.ownIdUrls = {\n' +
        '    setCookie: \'' + setCookieUrl + '\',\n' +
        '    setData: \'' + setDataUrl + '\',\n' +
        '    getJwt: \'' + getJwtUrl + '\',\n' +
        '    getMessage: \'' + getMessage + '\'\n' +
        '};\n' +
        'window.ownIdLocale = \'' + locale + '\'\n' +
        'window.ownIdLoginId = \'' + (notAuthenticated ? '' : customer.profile.email) + '\'\n' +
        'window.ownIdEnabled = ' + isEnabled() + '\n' +
        'window.ownidShowReturningUserPrompt = ' + ownidShowReturningUserPrompt + '\n' +
        'window.ownidShowReturningUserPromptOnSecondVisit = ' + ownidShowReturningUserPromptOnSecondVisit + '\n' +
        'window.ownidShowAuthNotification = ' + ownidShowAuthNotification + '\n' +
        'window.ownidShowAccountRecovery = ' + ownidShowAccountRecovery + '\n' +
        'window.ownidShowAccountRecovery = ' + ownidShowAccountRecovery + '\n' +
        'window.ownidEnableProfileUpdateWidgets = ' + ownidEnableProfileUpdateWidgets + '\n' +
        ';'
    );
}

module.exports = {
    ownidSdkSnippet: ownidSdkSnippet,
    isEnabled: isEnabled
};
